#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2024-07-16
# File  : bgp_topology/graphing/bgp_topology.py

from cmk.graphing.v1 import Title
from cmk.graphing.v1.graphs import Graph
from cmk.graphing.v1.metrics import Color, Metric, Unit, TimeNotation, AutoPrecision
from cmk.graphing.v1.perfometers import Closed, FocusRange, Open, Perfometer

from cmk_addons.plugins.bgp_topology.constants import METRIC_TIME_TAKEN

metric_topology_time_taken = Metric(
    name=METRIC_TIME_TAKEN,
    title=Title('Time taken'),
    unit=Unit(TimeNotation(), AutoPrecision(4)),
    color=Color.BLUE,
)

graph_topology_time_taken = Graph(
    name=METRIC_TIME_TAKEN,
    title=Title('Time taken'),
    compound_lines=[METRIC_TIME_TAKEN],
)

perfometer_topology_time_taken = Perfometer(
    name=METRIC_TIME_TAKEN,
    focus_range=FocusRange(Closed(0), Open(1)),
    segments=[METRIC_TIME_TAKEN]
)
